MnnEngineInfo class

Constructors

MnnEngineInfo({required String pluginVersion, required String mnnVersion, required String mnnCommit, required String abi, required int androidApiLevel, required String ndkVersion, required bool nativeLibraryLoaded, required String testRootPath})
const
MnnEngineInfo.fromMap(Object? value)
factory

Properties

abi → String
final
androidApiLevel → int
final
hashCode → int
The hash code for this object.
no setterinherited
mnnCommit → String
final
mnnVersion → String
final
nativeLibraryLoaded → bool
final
ndkVersion → String
final
pluginVersion → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testRootPath → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited