MnnLogEntry class

Constructors

MnnLogEntry({required int sequence, required int timestamp, required String level, required String tag, required String message})
const
MnnLogEntry.fromMap(Object? value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
level String
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
final
tag String
final
timestamp int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited