MnnModelInfo class

Constructors

MnnModelInfo({required String modelId, required String modelKey, required String displayName, required String modelDirPath, required String configPath, required int sizeBytes, required int importedAt, required bool isActive, bool supportsVision = false, bool supportsToolCalling = false, int? loadDurationMs, MnnBackend? backend, bool? useMmap, MnnPrecision? precision, int? threadNum, String? vendor, List<String> validationWarnings = const []})
const
MnnModelInfo.fromMap(Object? value)
factory

Properties

backend → MnnBackend?
Selected backend of a resident model; null for an unloaded model.
final
configPath → String
final
displayName → String
final
hashCode → int
The hash code for this object.
no setterinherited
importedAt → int
final
isActive → bool
final
loadDurationMs → int?
final
modelDirPath → String
final
modelId → String
final
modelKey → String
final
precision → MnnPrecision?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes → int
final
supportsToolCalling → bool
final
supportsVision → bool
final
threadNum → int?
final
useMmap → bool?
final
validationWarnings → List<String>
final
vendor → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited