MnnPortCheckResult class

Constructors

MnnPortCheckResult({required bool available, required bool ownedByMnn, String? message})
const
MnnPortCheckResult.fromMap(Object? value)
factory

Properties

available bool
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
ownedByMnn bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited