MnnServerInfo class

Constructors

MnnServerInfo({required bool running, required String host, required MnnServerBindMode bindMode, required String bindAddress, required int port, required String baseUrl, required String localBaseUrl, List<String> advertisedUrls = const [], bool requiresApiKey = false, int? startedAt, int? startDurationMs})
const
MnnServerInfo.fromMap(Object? value)
factory

Properties

advertisedUrls List<String>
final
baseUrl String
final
bindAddress String
final
bindMode MnnServerBindMode
final
hashCode int
The hash code for this object.
no setterinherited
host String
final
localBaseUrl String
final
port int
final
requiresApiKey bool
final
running bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDurationMs int?
final
startedAt int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited