MnnModelInfo class

Constructors

MnnModelInfo({required String modelId, required String modelKey, required String displayName, required String modelDirPath, required String configPath, required int sizeBytes, required int importedAt, required bool isActive, bool supportsVision = false, bool supportsToolCalling = false, int? loadDurationMs, String? vendor, List<String> validationWarnings = const []})
const
MnnModelInfo.fromMap(Object? value)
factory

Properties

configPath String
final
displayName String
final
hashCode int
The hash code for this object.
no setterinherited
importedAt int
final
isActive bool
final
loadDurationMs int?
final
modelDirPath String
final
modelId String
final
modelKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes int
final
supportsToolCalling bool
final
supportsVision bool
final
validationWarnings List<String>
final
vendor String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited