MnnRuntimeSnapshot class

Constructors

MnnRuntimeSnapshot({required int revision, required String engineState, required String modelState, required String serverState, required String generationState, MnnModelInfo? activeModel, MnnServerInfo? server, String? lastError})
const
MnnRuntimeSnapshot.fromMap(Object? value)
factory

Properties

activeModel MnnModelInfo?
final
engineState String
final
generationState String
final
hashCode int
The hash code for this object.
no setterinherited
lastError String?
final
modelState String
final
revision int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
server MnnServerInfo?
final
serverState String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited